@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-//@line 41 "/builds/slave/192-lnx64-xr/build/toolkit/mozapps/extensions/src/nsBlocklistService.js"
+//@line 41 "/builds/slave/m-2.0-lnx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
 */
 
 const Cc = Components.classes;
@@ -9,15 +9,20 @@ const Cr = Components.results;
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/FileUtils.jsm");
+Components.utils.import("resource://gre/modules/AddonManager.jsm");
+Components.utils.import("resource://gre/modules/Services.jsm");
 
 const TOOLKIT_ID                      = "toolkit@mozilla.org"
 const KEY_PROFILEDIR                  = "ProfD";
 const KEY_APPDIR                      = "XCurProcD";
 const FILE_BLOCKLIST                  = "blocklist.xml";
+const PREF_BLOCKLIST_LASTUPDATETIME   = "app.update.lastUpdateTime.blocklist-background-update-timer";
 const PREF_BLOCKLIST_URL              = "extensions.blocklist.url";
 const PREF_BLOCKLIST_ENABLED          = "extensions.blocklist.enabled";
 const PREF_BLOCKLIST_INTERVAL         = "extensions.blocklist.interval";
 const PREF_BLOCKLIST_LEVEL            = "extensions.blocklist.level";
+const PREF_BLOCKLIST_PINGCOUNTTOTAL   = "extensions.blocklist.pingCountTotal";
+const PREF_BLOCKLIST_PINGCOUNTVERSION = "extensions.blocklist.pingCountVersion";
 const PREF_PLUGINS_NOTIFYUSER         = "plugins.update.notifyUser";
 const PREF_GENERAL_USERAGENT_LOCALE   = "general.useragent.locale";
 const PREF_PARTNER_BRANCH             = "app.partner.";
@@ -64,7 +69,7 @@ XPCOMUtils.defineLazyGetter(this, "gABI", function bls_gABI() {
   catch (e) {
     LOG("BlockList Global gABI: XPCOM ABI unknown.");
   }
-//@line 113 "/builds/slave/192-lnx64-xr/build/toolkit/mozapps/extensions/src/nsBlocklistService.js"
+//@line 118 "/builds/slave/m-2.0-lnx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
   return abi;
 });
 
@@ -156,7 +161,7 @@ function restartApp() {
                    createInstance(Ci.nsISupportsPRBool);
   os.notifyObservers(cancelQuit, "quit-application-requested", null);
 
-  // Something aborted the quit process. 
+  // Something aborted the quit process.
   if (cancelQuit.data)
     return;
 
@@ -177,13 +182,13 @@ function matchesOSABI(blocklistElement) {
     if (choices.length > 0 && choices.indexOf(gApp.OS) < 0)
       return false;
   }
-  
+
   if (blocklistElement.hasAttribute("xpcomabi")) {
     choices = blocklistElement.getAttribute("xpcomabi").split(",");
     if (choices.length > 0 && choices.indexOf(gApp.XPCOMABI) < 0)
       return false;
   }
-  
+
   return true;
 }
 
@@ -220,7 +225,7 @@ function getUpdateChannel() {
   }
 
   try {
-    var partners = gPref.getChildList(PREF_PARTNER_BRANCH, { });
+    var partners = gPref.getChildList(PREF_PARTNER_BRANCH);
     if (partners.length) {
       channel += "-cck";
       partners.sort();
@@ -379,6 +384,34 @@ Blocklist.prototype = {
       return;
     }
 
+    var pingCountVersion = getPref("getIntPref", PREF_BLOCKLIST_PINGCOUNTVERSION, 0);
+    var pingCountTotal = getPref("getIntPref", PREF_BLOCKLIST_PINGCOUNTTOTAL, 1);
+    var daysSinceLastPing = 0;
+    if (pingCountVersion < 1 || pingCountTotal < 1) {
+      daysSinceLastPing = pingCountVersion == 0 ? "new" : "reset";
+      if (pingCountVersion < 1)
+        pingCountVersion = 1;
+      if (pingCountTotal < 1)
+        pingCountTotal = 1;
+    }
+    else {
+      // Seconds in one day is used because nsIUpdateTimerManager stores the
+      // last update time in seconds.
+      let secondsInDay = 60 * 60 * 24;
+      let lastUpdateTime = getPref("getIntPref", PREF_BLOCKLIST_LASTUPDATETIME, 0);
+      if (lastUpdateTime == 0) {
+        daysSinceLastPing = "invalid";
+      }
+      else {
+        let now = Math.round(Date.now() / 1000);
+        daysSinceLastPing = Math.floor((now - lastUpdateTime) / secondsInDay);
+      }
+
+      if (daysSinceLastPing == 0 || daysSinceLastPing == "invalid") {
+        pingCountVersion = pingCountTotal = "invalid";
+      }
+    }
+
     dsURI = dsURI.replace(/%APP_ID%/g, gApp.ID);
     dsURI = dsURI.replace(/%APP_VERSION%/g, gApp.version);
     dsURI = dsURI.replace(/%PRODUCT%/g, gApp.name);
@@ -393,8 +426,34 @@ Blocklist.prototype = {
                       getDistributionPrefValue(PREF_APP_DISTRIBUTION));
     dsURI = dsURI.replace(/%DISTRIBUTION_VERSION%/g,
                       getDistributionPrefValue(PREF_APP_DISTRIBUTION_VERSION));
+    dsURI = dsURI.replace(/%PING_COUNT%/g, pingCountVersion);
+    dsURI = dsURI.replace(/%TOTAL_PING_COUNT%/g, pingCountTotal);
+    dsURI = dsURI.replace(/%DAYS_SINCE_LAST_PING%/g, daysSinceLastPing);
     dsURI = dsURI.replace(/\+/g, "%2B");
 
+    // Under normal operations it will take around 5,883,516 years before the
+    // preferences used to store pingCountVersion and pingCountTotal will rollover
+    // so this code doesn't bother trying to do the "right thing" here.
+    if (pingCountVersion != "invalid") {
+      pingCountVersion++;
+      if (pingCountVersion > 2147483647) {
+        // Rollover to -1 if the value is greater than what is support by an
+        // integer preference. The -1 indicates that the counter has been reset.
+        pingCountVersion = -1;
+      }
+      gPref.setIntPref(PREF_BLOCKLIST_PINGCOUNTVERSION, pingCountVersion);
+    }
+
+    if (pingCountTotal != "invalid") {
+      pingCountTotal++;
+      if (pingCountTotal > 2147483647) {
+        // Rollover to 1 if the value is greater than what is support by an
+        // integer preference.
+        pingCountTotal = -1;
+      }
+      gPref.setIntPref(PREF_BLOCKLIST_PINGCOUNTTOTAL, pingCountTotal);
+    }
+
     // Verify that the URI is valid
     try {
       var uri = newURI(dsURI);
@@ -466,10 +525,14 @@ Blocklist.prototype = {
       request = aEvent.target.channel.QueryInterface(Ci.nsIRequest);
       status = request.status;
     }
-    var statusText = request.statusText;
+    var statusText = "nsIXMLHttpRequest channel unavailable";
     // When status is 0 we don't have a valid channel.
-    if (status == 0)
-      statusText = "nsIXMLHttpRequest channel unavailable";
+    if (status != 0) {
+      try {
+        statusText = request.statusText;
+      } catch (e) {
+      }
+    }
     LOG("Blocklist:onError: There was an error loading the blocklist file\r\n" +
         statusText);
   },
@@ -495,7 +558,7 @@ Blocklist.prototype = {
   },
 
   /**
-//@line 592 "/builds/slave/192-lnx64-xr/build/toolkit/mozapps/extensions/src/nsBlocklistService.js"
+//@line 655 "/builds/slave/m-2.0-lnx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
    */
 
   _loadBlocklistFromFile: function(file) {
@@ -524,10 +587,25 @@ Blocklist.prototype = {
       }
 
       var childNodes = doc.documentElement.childNodes;
-      this._addonEntries = this._processItemNodes(childNodes, "em",
-                                                  this._handleEmItemNode);
-      this._pluginEntries = this._processItemNodes(childNodes, "plugin",
-                                                   this._handlePluginItemNode);
+      for (var i = 0; i < childNodes.length; ++i) {
+        var element = childNodes[i];
+        if (!(element instanceof Ci.nsIDOMElement))
+          continue;
+        switch (element.localName) {
+        case "emItems":
+          this._addonEntries = this._processItemNodes(element.childNodes, "em",
+                                                      this._handleEmItemNode);
+          break;
+        case "pluginItems":
+          this._pluginEntries = this._processItemNodes(element.childNodes, "plugin",
+                                                       this._handlePluginItemNode);
+          break;
+        default:
+          Services.obs.notifyObservers(element,
+                                       "blocklist-data-" + element.localName,
+                                       null);
+        }
+      }
     }
     catch (e) {
       LOG("Blocklist::_loadBlocklistFromFile: Error constructing blocklist " + e);
@@ -536,21 +614,8 @@ Blocklist.prototype = {
     fileStream.close();
   },
 
-  _processItemNodes: function(deChildNodes, prefix, handler) {
+  _processItemNodes: function(itemNodes, prefix, handler) {
     var result = [];
-    var itemNodes;
-    var containerName = prefix + "Items";
-    for (var i = 0; i < deChildNodes.length; ++i) {
-      var emItemsElement = deChildNodes.item(i);
-      if (emItemsElement instanceof Ci.nsIDOMElement &&
-          emItemsElement.localName == containerName) {
-        itemNodes = emItemsElement.childNodes;
-        break;
-      }
-    }
-    if (!itemNodes)
-      return result;
-
     var itemName = prefix + "Item";
     for (var i = 0; i < itemNodes.length; ++i) {
       var blocklistElement = itemNodes.item(i);
@@ -593,6 +658,7 @@ Blocklist.prototype = {
       matches: {},
       versions: []
     };
+    var hasMatch = false;
     for (var x = 0; x < matchNodes.length; ++x) {
       var matchElement = matchNodes.item(x);
       if (!(matchElement instanceof Ci.nsIDOMElement))
@@ -600,11 +666,19 @@ Blocklist.prototype = {
       if (matchElement.localName == "match") {
         var name = matchElement.getAttribute("name");
         var exp = matchElement.getAttribute("exp");
-        blockEntry.matches[name] = new RegExp(exp, "m");
+        try {
+          blockEntry.matches[name] = new RegExp(exp, "m");
+          hasMatch = true;
+        } catch (e) {
+          // Ignore invalid regular expressions
+        }
       }
       if (matchElement.localName == "versionRange")
         blockEntry.versions.push(new BlocklistItemData(matchElement));
     }
+    // Plugin entries require *something* to match to an actual plugin
+    if (!hasMatch)
+      return;
     // Add a default versionRange if there wasn't one specified
     if (blockEntry.versions.length == 0)
       blockEntry.versions.push(new BlocklistItemData(null));
@@ -677,107 +751,134 @@ Blocklist.prototype = {
   _blocklistUpdated: function(oldAddonEntries, oldPluginEntries) {
     var addonList = [];
 
-    var em = Cc["@mozilla.org/extensions/manager;1"].
-             getService(Ci.nsIExtensionManager);
-    var addons = em.updateAndGetNewBlocklistedItems({});
+    var self = this;
+    AddonManager.getAddonsByTypes(["extension", "theme", "locale"], function(addons) {
 
-    for (let i = 0; i < addons.length; i++) {
-      let oldState = -1;
-      if (oldAddonEntries)
-        oldState = this._getAddonBlocklistState(addons[i].id, addons[i].version,
-                                                oldAddonEntries);
-      let state = this.getAddonBlocklistState(addons[i].id, addons[i].version);
-      // We don't want to re-warn about items
-      if (state == oldState)
-        continue;
+      for (let i = 0; i < addons.length; i++) {
+        let oldState = Ci.nsIBlocklistService.STATE_NOTBLOCKED;
+        if (oldAddonEntries)
+          oldState = self._getAddonBlocklistState(addons[i].id, addons[i].version,
+                                                  oldAddonEntries);
+        let state = self.getAddonBlocklistState(addons[i].id, addons[i].version);
 
-      addonList.push({
-        name: addons[i].name,
-        version: addons[i].version,
-        icon: addons[i].iconURL,
-        disable: false,
-        blocked: state == Ci.nsIBlocklistService.STATE_BLOCKED,
-        item: addons[i]
-      });
-    }
+        LOG("Blocklist state for " + addons[i].id + " changed from " +
+            oldState + " to " + state);
 
-    var phs = Cc["@mozilla.org/plugin/host;1"].
-              getService(Ci.nsIPluginHost);
-    var plugins = phs.getPluginTags({});
+        // Don't warn about add-ons becoming unblocked.
+        if (state == 0)
+          continue;
 
-    for (let i = 0; i < plugins.length; i++) {
-      let oldState = -1;
-      if (oldPluginEntries)
-        oldState = this._getPluginBlocklistState(plugins[i], oldPluginEntries);
-      let state = this.getPluginBlocklistState(plugins[i]);
-      // We don't want to re-warn about items
-      if (state == oldState)
-        continue;
+        // We don't want to re-warn about add-ons
+        if (state == oldState)
+          continue;
 
-      if (plugins[i].blocklisted) {
-        if (state == Ci.nsIBlocklistService.STATE_SOFTBLOCKED)
-          plugins[i].disabled = true;
-      }
-      else if (!plugins[i].disabled && state != Ci.nsIBlocklistService.STATE_NOT_BLOCKED) {
-        if (state == Ci.nsIBlocklistService.STATE_OUTDATED) {
-          gPref.setBoolPref(PREF_PLUGINS_NOTIFYUSER, true);
-        }
-        else {
-          addonList.push({
-            name: plugins[i].name,
-            version: plugins[i].version,
-            icon: "chrome://mozapps/skin/plugins/pluginGeneric.png",
-            disable: false,
-            blocked: state == Ci.nsIBlocklistService.STATE_BLOCKED,
-            item: plugins[i]
-          });
+        // If an add-on has dropped from hard to soft blocked just mark it as
+        // user disabled and don't warn about it.
+        if (state == Ci.nsIBlocklistService.STATE_SOFTBLOCKED &&
+            oldState == Ci.nsIBlocklistService.STATE_BLOCKED) {
+          addons[i].userDisabled = true;
+          continue;
         }
+
+        // If the add-on is already disabled for some reason then don't warn
+        // about it
+        if (!addons[i].isActive)
+          continue;
+
+        addonList.push({
+          name: addons[i].name,
+          version: addons[i].version,
+          icon: addons[i].iconURL,
+          disable: false,
+          blocked: state == Ci.nsIBlocklistService.STATE_BLOCKED,
+          item: addons[i]
+        });
       }
-      plugins[i].blocklisted = state == Ci.nsIBlocklistService.STATE_BLOCKED;
-    }
 
-    if (addonList.length == 0)
-      return;
+      AddonManagerPrivate.updateAddonAppDisabledStates();
 
-    var args = {
-      restart: false,
-      list: addonList
-    };
-    // This lets the dialog get the raw js object
-    args.wrappedJSObject = args;
+      var phs = Cc["@mozilla.org/plugin/host;1"].
+                getService(Ci.nsIPluginHost);
+      var plugins = phs.getPluginTags();
 
-    var ww = Cc["@mozilla.org/embedcomp/window-watcher;1"].
-             getService(Ci.nsIWindowWatcher);
-    ww.openWindow(null, URI_BLOCKLIST_DIALOG, "",
-                  "chrome,centerscreen,dialog,modal,titlebar", args);
+      for (let i = 0; i < plugins.length; i++) {
+        let oldState = -1;
+        if (oldPluginEntries)
+          oldState = self._getPluginBlocklistState(plugins[i], oldPluginEntries);
+        let state = self.getPluginBlocklistState(plugins[i]);
+        LOG("Blocklist state for " + plugins[i].name + " changed from " +
+            oldState + " to " + state);
+        // We don't want to re-warn about items
+        if (state == oldState)
+          continue;
 
-    for (let i = 0; i < addonList.length; i++) {
-      if (!addonList[i].disable)
-        continue;
+        if (plugins[i].blocklisted) {
+          if (state == Ci.nsIBlocklistService.STATE_SOFTBLOCKED)
+            plugins[i].disabled = true;
+        }
+        else if (!plugins[i].disabled && state != Ci.nsIBlocklistService.STATE_NOT_BLOCKED) {
+          if (state == Ci.nsIBlocklistService.STATE_OUTDATED) {
+            gPref.setBoolPref(PREF_PLUGINS_NOTIFYUSER, true);
+          }
+          else {
+            addonList.push({
+              name: plugins[i].name,
+              version: plugins[i].version,
+              icon: "chrome://mozapps/skin/plugins/pluginGeneric.png",
+              disable: false,
+              blocked: state == Ci.nsIBlocklistService.STATE_BLOCKED,
+              item: plugins[i]
+            });
+          }
+        }
+        plugins[i].blocklisted = state == Ci.nsIBlocklistService.STATE_BLOCKED;
+      }
 
-      if (addonList[i].item instanceof Ci.nsIUpdateItem)
-        em.disableItem(addonList[i].item.id);
-      else if (addonList[i].item instanceof Ci.nsIPluginTag)
-        addonList[i].item.disabled = true;
-      else
-        LOG("Blocklist::_blocklistUpdated: Unknown add-on type: " +
-            addonList[i].item);
-    }
+      if (addonList.length == 0)
+        return;
 
-    if (args.restart)
-      restartApp();
+      if ("@mozilla.org/addons/blocklist-prompt;1" in Cc) {
+        try {
+          let blockedPrompter = Cc["@mozilla.org/addons/blocklist-prompt;1"]
+                                 .getService(Ci.nsIBlocklistPrompt);
+          blockedPrompter.prompt(addonList);
+        } catch (e) {
+          LOG(e);
+        }
+        return;
+      }
+
+      var args = {
+        restart: false,
+        list: addonList
+      };
+      // This lets the dialog get the raw js object
+      args.wrappedJSObject = args;
+
+      var ww = Cc["@mozilla.org/embedcomp/window-watcher;1"].
+               getService(Ci.nsIWindowWatcher);
+      ww.openWindow(null, URI_BLOCKLIST_DIALOG, "",
+                    "chrome,centerscreen,dialog,modal,titlebar", args);
+
+      for (let i = 0; i < addonList.length; i++) {
+        if (!addonList[i].disable)
+          continue;
+
+        if (addonList[i].item instanceof Ci.nsIPluginTag)
+          addonList[i].item.disabled = true;
+        else
+          addonList[i].item.userDisabled = true;
+      }
+
+      if (args.restart)
+        restartApp();
+    });
   },
 
-  classDescription: "Blocklist Service",
-  contractID: "@mozilla.org/extensions/blocklist;1",
   classID: Components.ID("{66354bc9-7ed1-4692-ae1d-8da97d6b205e}"),
   QueryInterface: XPCOMUtils.generateQI([Ci.nsIObserver,
                                          Ci.nsIBlocklistService,
                                          Ci.nsITimerCallback]),
-  _xpcom_categories: [{ category: "update-timer",
-                        value: "@mozilla.org/extensions/blocklist;1," +
-                               "getService,blocklist-background-update-timer," +
-                               PREF_BLOCKLIST_INTERVAL + ",86400" }]
 };
 
 /**
@@ -938,6 +1039,4 @@ BlocklistItemData.prototype = {
   }
 };
 
-function NSGetModule(aCompMgr, aFileSpec) {
-  return XPCOMUtils.generateModule([Blocklist]);
-}
+var NSGetFactory = XPCOMUtils.generateNSGetFactory([Blocklist]);
