@@ -1,5 +1,7 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-//@line 41 "/builds/slave/192-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
+//@line 41 "/builds/slave/m-2.0-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
+
+Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
 const nsIFile             = Components.interfaces.nsIFile;
 const nsIINIParser        = Components.interfaces.nsIINIParser;
@@ -167,16 +169,14 @@ function createExtractor(aFile) {
   return new zipExtractor(aFile);
 }
 
-const AppInstall = {
+function AppInstall() {
+}
+
+AppInstall.prototype = {
+  classID: Components.ID("{00790a19-27e2-4d9a-bef0-244080feabfd}"),
 
   /* nsISupports */
-  QueryInterface : function ai_QI(iid) {
-    if (iid.equals(nsIXULAppInstall) ||
-        iid.equals(nsISupports))
-      return this;
-
-    throw Components.results.NS_ERROR_NO_INTERFACE;
-  },
+  QueryInterface : XPCOMUtils.generateQI([nsIXULAppInstall]),
 
   /* nsIXULAppInstall */
   installApplication : function ai_IA(aAppFile, aDirectory, aLeafName) {
@@ -193,13 +193,13 @@ const AppInstall = {
     catch (e) { }
 
     if (aDirectory == null) {
-//@line 244 "/builds/slave/192-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
+//@line 244 "/builds/slave/m-2.0-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
       aDirectory = Components.classes["@mozilla.org/file/local;1"].
         createInstance(nsILocalFile);
-      aDirectory.initWithPath("/usr/lib");
+      aDirectory.initWithPath("/usr/local/lib");
       if (vendor)
         aDirectory.append(vendor.toLowerCase());
-//@line 251 "/builds/slave/192-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
+//@line 251 "/builds/slave/m-2.0-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
     }
     else {
       aDirectory = aDirectory.clone();
@@ -210,9 +210,9 @@ const AppInstall = {
     }
 
     if (aLeafName == "") {
-//@line 267 "/builds/slave/192-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
+//@line 267 "/builds/slave/m-2.0-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
       aLeafName = appName.toLowerCase();
-//@line 270 "/builds/slave/192-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
+//@line 270 "/builds/slave/m-2.0-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
     }
 
     aDirectory.append(aLeafName);
@@ -220,81 +220,15 @@ const AppInstall = {
       aDirectory.create(nsIFile.DIRECTORY_TYPE, 0755);
     }
 
-//@line 341 "/builds/slave/192-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
+//@line 341 "/builds/slave/m-2.0-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
     extractor.copyTo(aDirectory);
 
     var xulrunnerBinary = getDirectoryKey("GreD");
     xulrunnerBinary.append("xulrunner-stub");
 
     xulrunnerBinary.copyTo(aDirectory, appName.toLowerCase() + "");
-//@line 348 "/builds/slave/192-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
+//@line 348 "/builds/slave/m-2.0-lnx64-xr/build/xulrunner/setup/nsXULAppInstall.js"
   }
 };
 
-const AppInstallFactory = {
-  /* nsISupports */
-  QueryInterface : function aif_QI(iid) {
-    if (iid.equals(Components.interfaces.nsIFactory) ||
-        iid.equals(nsISupports))
-      return this;
-
-    throw Components.results.NS_ERROR_NO_INTERFACE;
-  },
-
-  /* nsIFactory */
-  createInstance : function aif_CI(aOuter, aIID) {
-    if (aOuter)
-      throw Components.results.NS_ERROR_NO_AGGREGATION;
-
-    return AppInstall.QueryInterface(aIID);
-  },
-
-  lockFactory : function aif_lock(aLock) { }
-};
-
-const AppInstallContractID = "@mozilla.org/xulrunner/app-install-service;1";
-const AppInstallCID = Components.ID("{00790a19-27e2-4d9a-bef0-244080feabfd}");
-
-const AppInstallModule = {
-  /* nsISupports */
-  QueryInterface : function mod_QI(iid) {
-    if (iid.equals(Components.interfaces.nsIModule) ||
-        iid.equals(nsISupports))
-      return this;
-
-    throw Components.results.NS_ERROR_NO_INTERFACE;
-  },
-
-  /* nsIModule */
-  getClassObject : function mod_gco(aCompMgr, aClass, aIID) {
-    if (aClass.equals(AppInstallCID))
-      return AppInstallFactory.QueryInterface(aIID);
-
-    return Components.results.NS_ERROR_FACTORY_NOT_REGISTERED;
-  },
-
-  registerSelf : function mod_regself(aCompMgr, aLocation,
-                                      aLoaderStr, aType) {
-    var reg = aCompMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
-    reg.registerFactoryLocation(AppInstallCID,
-                                "nsXULAppInstall",
-                                AppInstallContractID,
-                                aLocation,
-                                aLoaderStr,
-                                aType);
-  },
-
-  unregisterSelf : function mod_unreg(aCompMgr, aLocation, aLoaderStr) {
-    var reg = aCompMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
-    reg.unregisterFactoryLocation(AppInstallCID,
-                                  aLocation);
-  },
-
-  canUnload : function mod_unload(aCompMgr) {
-    return true;
-  }
-};
-
-function NSGetModule(compMgr, fileSpec) {
-  return AppInstallModule;
-}
+const NSGetFactory = XPCOMUtils.generateNSGetFactory([AppInstall]);
