@@ -1,4 +1,4 @@
-//@line 43 "/builds/slave/mozilla-1.9.1-linux64-xulrunner/build/toolkit/content/contentAreaUtils.js"
+//@line 43 "/builds/slave/m-2.0-lnx64-xr/build/toolkit/content/contentAreaUtils.js"
 
 var ContentAreaUtils = {
   get ioService() {
@@ -6,6 +6,14 @@ var ContentAreaUtils = {
     return this.ioService =
       Components.classes["@mozilla.org/network/io-service;1"]
                 .getService(Components.interfaces.nsIIOService);
+  },
+
+  get stringBundle() {
+    delete this.stringBundle;
+    return this.stringBundle =
+      Components.classes["@mozilla.org/intl/stringbundle;1"]
+                .getService(Components.interfaces.nsIStringBundleService)
+                .createBundle("chrome://global/locale/contentAreaCommands.properties");
   }
 }
 
@@ -113,13 +121,6 @@ function saveImageURL(aURL, aFileName, aFilePickerTitleKey, aShouldBypassCache,
                aSkipPrompt, null);
 }
 
-function saveFrameDocument()
-{
-  var focusedWindow = document.commandDispatcher.focusedWindow;
-  if (isContentFrame(focusedWindow))
-    saveDocument(focusedWindow.document);
-}
-
 function saveDocument(aDocument, aSkipPrompt)
 {
   if (!aDocument)
@@ -388,9 +389,9 @@ function internalPersist(persistArgs)
       filesFolder = persistArgs.targetFile.clone();
 
       var nameWithoutExtension = getFileBaseName(filesFolder.leafName);
-      var filesFolderLeafName = getStringBundle().formatStringFromName("filesFolder",
-                                                                       [nameWithoutExtension],
-                                                                       1);
+      var filesFolderLeafName =
+        ContentAreaUtils.stringBundle
+                        .formatStringFromName("filesFolder", [nameWithoutExtension], 1);
 
       filesFolder.leafName = filesFolderLeafName;
     }
@@ -519,15 +520,6 @@ function getTargetFile(aFpP, /* optional */ aSkipPrompt)
   if (!aSkipPrompt)
     useDownloadDir = false;
 
-  var inPrivateBrowsing = false;
-  try {
-    var pbs = Components.classes["@mozilla.org/privatebrowsing;1"]
-                        .getService(Components.interfaces.nsIPrivateBrowsingService);
-    inPrivateBrowsing = pbs.privateBrowsingEnabled;
-  }
-  catch (e) {
-  }
-
   // Default to the user's default downloads directory configured
   // through download prefs.
   var dlMgr = Components.classes["@mozilla.org/download-manager;1"]
@@ -549,11 +541,7 @@ function getTargetFile(aFpP, /* optional */ aSkipPrompt)
     // file picker if it is still valid. Otherwise, keep the default of the
     // user's default downloads directory. If it doesn't exist, it will be
     // changed to the user's desktop later.
-    var lastDir;
-    if (inPrivateBrowsing && gDownloadLastDir.file)
-      lastDir = gDownloadLastDir.file;
-    else
-      lastDir = prefs.getComplexValue("lastDir", nsILocalFile);
+    var lastDir = gDownloadLastDir.file;
     if (lastDir.exists()) {
       dir = lastDir;
       dirExists = true;
@@ -569,8 +557,7 @@ function getTargetFile(aFpP, /* optional */ aSkipPrompt)
 
   var fp = makeFilePicker();
   var titleKey = aFpP.fpTitleKey || "SaveLinkTitle";
-  var bundle = getStringBundle();
-  fp.init(window, bundle.GetStringFromName(titleKey),
+  fp.init(window, ContentAreaUtils.stringBundle.GetStringFromName(titleKey),
           Components.interfaces.nsIFilePicker.modeSave);
 
   fp.displayDirectory = dir;
@@ -598,10 +585,7 @@ function getTargetFile(aFpP, /* optional */ aSkipPrompt)
 
   // Do not store the last save directory as a pref inside the private browsing mode
   var directory = fp.file.parent.QueryInterface(nsILocalFile);
-  if (inPrivateBrowsing)
-    gDownloadLastDir.file = directory;
-  else
-    prefs.setComplexValue("lastDir", nsILocalFile, directory);
+  gDownloadLastDir.file = directory;
 
   fp.file.leafName = validateFileName(fp.file.leafName);
   
@@ -652,7 +636,6 @@ const SAVEMODE_COMPLETE_TEXT = 0x02;
 // filter must be the third filter appended.
 function appendFiltersForContentType(aFilePicker, aContentType, aFileExtension, aSaveMode)
 {
-  var bundle = getStringBundle();
   // The bundle name for saving only a specific content type.
   var bundleName;
   // The corresponding filter string for a specific content type.
@@ -708,10 +691,12 @@ function appendFiltersForContentType(aFilePicker, aContentType, aFileExtension,
   }
 
   if (aSaveMode & SAVEMODE_COMPLETE_DOM) {
-    aFilePicker.appendFilter(bundle.GetStringFromName("WebPageCompleteFilter"), filterString);
+    aFilePicker.appendFilter(ContentAreaUtils.stringBundle.GetStringFromName("WebPageCompleteFilter"),
+                             filterString);
     // We should always offer a choice to save document only if
     // we allow saving as complete.
-    aFilePicker.appendFilter(bundle.GetStringFromName(bundleName), filterString);
+    aFilePicker.appendFilter(ContentAreaUtils.stringBundle.GetStringFromName(bundleName),
+                             filterString);
   }
 
   if (aSaveMode & SAVEMODE_COMPLETE_TEXT)
@@ -724,26 +709,23 @@ function appendFiltersForContentType(aFilePicker, aContentType, aFileExtension,
 function getPostData(aDocument)
 {
   try {
-    var sessionHistory = aDocument.defaultView
-                                  .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
-                                  .getInterface(Components.interfaces.nsIWebNavigation)
-                                  .sessionHistory;
-    return sessionHistory.getEntryAtIndex(sessionHistory.index, false)
-                         .QueryInterface(Components.interfaces.nsISHEntry)
-                         .postData;
+    // Find the session history entry corresponding to the given document. In
+    // the current implementation, nsIWebPageDescriptor.currentDescriptor always
+    // returns a session history entry.
+    var sessionHistoryEntry =
+        aDocument.defaultView
+                 .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+                 .getInterface(Components.interfaces.nsIWebNavigation)
+                 .QueryInterface(Components.interfaces.nsIWebPageDescriptor)
+                 .currentDescriptor
+                 .QueryInterface(Components.interfaces.nsISHEntry);
+    return sessionHistoryEntry.postData;
   }
   catch (e) {
   }
   return null;
 }
 
-function getStringBundle()
-{
-  return Components.classes["@mozilla.org/intl/stringbundle;1"]
-                   .getService(Components.interfaces.nsIStringBundleService)
-                   .createBundle("chrome://global/locale/contentAreaCommands.properties");
-}
-
 // Get the preferences branch ("browser.download." for normal 'save' mode)...
 function getPrefsBrowserDownload(branch)
 {
@@ -886,7 +868,7 @@ function getDefaultFileName(aDefaultFileName, aURI, aDocument,
   }
   try {
     // 7) Use the default file name
-    return getStringBundle().GetStringFromName("DefaultSaveFileName");
+    return ContentAreaUtils.stringBundle.GetStringFromName("DefaultSaveFileName");
   } catch (e) {
     //in case localized string cannot be found
   }
@@ -915,7 +897,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 963 "/builds/slave/mozilla-1.9.1-linux64-xulrunner/build/toolkit/content/contentAreaUtils.js"
+//@line 945 "/builds/slave/m-2.0-lnx64-xr/build/toolkit/content/contentAreaUtils.js"
 
   // Remove leading dots
   aFile = aFile.replace(/^\.+/, "");
