@@ -1,6 +1,6 @@
 function closeWindow(aClose, aPromptFunction)
 {
-//@line 5 "/builds/slave/192-lnx64-xr/build/toolkit/content/globalOverlay.js"
+//@line 5 "/builds/slave/2.0-lnx64-xr/build/toolkit/content/globalOverlay.js"
   var windowCount = 0;
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
@@ -22,10 +22,10 @@ function closeWindow(aClose, aPromptFunction)
   }
 
   // If we're down to the last window and someone tries to shut down, check to make sure we can!
-  if (windowCount == 1 && !canQuitApplication())
+  if (windowCount == 1 && !canQuitApplication("lastwindow"))
     return false;
   else if (windowCount != 1 || inPrivateBrowsing)
-//@line 30 "/builds/slave/192-lnx64-xr/build/toolkit/content/globalOverlay.js"
+//@line 30 "/builds/slave/2.0-lnx64-xr/build/toolkit/content/globalOverlay.js"
     if (typeof(aPromptFunction) == "function" && !aPromptFunction())
       return false;
 
@@ -35,7 +35,7 @@ function closeWindow(aClose, aPromptFunction)
   return true;
 }
 
-function canQuitApplication()
+function canQuitApplication(aData)
 {
   var os = Components.classes["@mozilla.org/observer-service;1"]
                      .getService(Components.interfaces.nsIObserverService);
@@ -44,7 +44,7 @@ function canQuitApplication()
   try {
     var cancelQuit = Components.classes["@mozilla.org/supports-PRBool;1"]
                               .createInstance(Components.interfaces.nsISupportsPRBool);
-    os.notifyObservers(cancelQuit, "quit-application-requested", null);
+    os.notifyObservers(cancelQuit, "quit-application-requested", aData || null);
     
     // Something aborted the quit process. 
     if (cancelQuit.data)
