@@ -1,4 +1,4 @@
-//@line 41 "/builds/slave/lorentz-linux64-xulrunner/build/toolkit/components/printing/content/printProgress.js"
+//@line 41 "/builds/slave/m-2.0-lnx64-xr/build/toolkit/components/printing/content/printProgress.js"
 
 // dialog is just an array we'll use to store various properties from the dialog document...
 var dialog;
@@ -14,7 +14,7 @@ var docURL   = "";
 var progressParams = null;
 var switchUI = true;
 
-function elipseString(aStr, doFront)
+function ellipseString(aStr, doFront)
 {
   if (aStr.length > 3 && (aStr.substr(0, 3) == "..." || aStr.substr(aStr.length-4, 3) == "...")) {
     return aStr;
@@ -100,7 +100,7 @@ var progressListener = {
 
       if (progressParams)
       {
-        var docTitleStr = elipseString(progressParams.docTitle, false);
+        var docTitleStr = ellipseString(progressParams.docTitle, false);
         if (docTitleStr != docTitle) {
           docTitle = docTitleStr;
           dialog.title.value = docTitle;
@@ -109,7 +109,7 @@ var progressListener = {
         if (docURLStr != docURL && dialog.title != null) {
           docURL = docURLStr;
           if (docTitle == "") {
-            dialog.title.value = elipseString(docURLStr, true);
+            dialog.title.value = ellipseString(docURLStr, true);
           }
         }
       }
@@ -209,8 +209,8 @@ function onLoad() {
       progressParams = window.arguments[1].QueryInterface(Components.interfaces.nsIPrintProgressParams)
       if (progressParams)
       {
-        docTitle = elipseString(progressParams.docTitle, false);
-        docURL   = elipseString(progressParams.docURL, true);
+        docTitle = ellipseString(progressParams.docTitle, false);
+        docURL   = ellipseString(progressParams.docURL, true);
       }
     }
 
